#[repr(transparent)]pub struct PercentModifier(pub Nat16);Tuple Fields
0: Nat16Trait Implementations
Sourceimpl Add<PercentModifier> for Nat16
impl Add<PercentModifier> for Nat16
Sourcetype Output = PercentModifier
type Output = PercentModifier
The resulting type after applying the
+ operator.Sourceimpl Add<u16> for PercentModifier
impl Add<u16> for PercentModifier
Sourceimpl Add for PercentModifier
impl Add for PercentModifier
Sourceimpl AddAssign<u16> for PercentModifier
impl AddAssign<u16> for PercentModifier
Sourcefn add_assign(&mut self, other: Nat16)
fn add_assign(&mut self, other: Nat16)
Performs the
+= operation. Read moreSourceimpl AddAssign for PercentModifier
impl AddAssign for PercentModifier
Sourcefn add_assign(&mut self, other: PercentModifier)
fn add_assign(&mut self, other: PercentModifier)
Performs the
+= operation. Read moreSourceimpl Clone for PercentModifier
impl Clone for PercentModifier
Sourcefn clone(&self) -> PercentModifier
fn clone(&self) -> PercentModifier
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PercentModifier
impl Debug for PercentModifier
Sourceimpl Default for PercentModifier
impl Default for PercentModifier
Sourcefn default() -> PercentModifier
fn default() -> PercentModifier
Returns the “default value” for a type. Read more
Sourceimpl Deref for PercentModifier
impl Deref for PercentModifier
Sourceimpl DerefMut for PercentModifier
impl DerefMut for PercentModifier
Sourceimpl<'de> Deserialize<'de> for PercentModifier
impl<'de> Deserialize<'de> for PercentModifier
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for PercentModifier
impl Display for PercentModifier
Sourceimpl FieldValue for PercentModifier
impl FieldValue for PercentModifier
Sourceimpl Filterable for PercentModifier
impl Filterable for PercentModifier
type Filter = <u16 as Filterable>::Filter
type ListFilter = <u16 as Filterable>::ListFilter
Sourceimpl<T> From<T> for PercentModifier
impl<T> From<T> for PercentModifier
Sourceimpl Hash for PercentModifier
impl Hash for PercentModifier
Sourceimpl Inner<u16> for PercentModifier
impl Inner<u16> for PercentModifier
Sourceimpl<__derive_more_Rhs> Mul<__derive_more_Rhs> for PercentModifier
impl<__derive_more_Rhs> Mul<__derive_more_Rhs> for PercentModifier
Sourceimpl<__derive_more_Rhs> MulAssign<__derive_more_Rhs> for PercentModifier
impl<__derive_more_Rhs> MulAssign<__derive_more_Rhs> for PercentModifier
Sourcefn mul_assign(&mut self, __rhs: __derive_more_Rhs)
fn mul_assign(&mut self, __rhs: __derive_more_Rhs)
Performs the
*= operation. Read moreSourceimpl NumCast for PercentModifier
impl NumCast for PercentModifier
Sourceimpl FromPrimitive for PercentModifier
impl FromPrimitive for PercentModifier
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u128(n: u128) -> Option<Self>
fn from_u128(n: u128) -> Option<Self>
Converts an
u128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourceimpl ToPrimitive for PercentModifier
impl ToPrimitive for PercentModifier
Sourcefn to_i64(&self) -> Option<i64>
fn to_i64(&self) -> Option<i64>
Converts the value of
self to an i64. If the value cannot be
represented by an i64, then None is returned.Sourcefn to_u64(&self) -> Option<u64>
fn to_u64(&self) -> Option<u64>
Converts the value of
self to a u64. If the value cannot be
represented by a u64, then None is returned.Sourcefn to_isize(&self) -> Option<isize>
fn to_isize(&self) -> Option<isize>
Converts the value of
self to an isize. If the value cannot be
represented by an isize, then None is returned.Sourcefn to_i8(&self) -> Option<i8>
fn to_i8(&self) -> Option<i8>
Converts the value of
self to an i8. If the value cannot be
represented by an i8, then None is returned.Sourcefn to_i16(&self) -> Option<i16>
fn to_i16(&self) -> Option<i16>
Converts the value of
self to an i16. If the value cannot be
represented by an i16, then None is returned.Sourcefn to_i32(&self) -> Option<i32>
fn to_i32(&self) -> Option<i32>
Converts the value of
self to an i32. If the value cannot be
represented by an i32, then None is returned.Sourcefn to_i128(&self) -> Option<i128>
fn to_i128(&self) -> Option<i128>
Converts the value of
self to an i128. If the value cannot be
represented by an i128 (i64 under the default implementation), then
None is returned. Read moreSourcefn to_usize(&self) -> Option<usize>
fn to_usize(&self) -> Option<usize>
Converts the value of
self to a usize. If the value cannot be
represented by a usize, then None is returned.Sourcefn to_u8(&self) -> Option<u8>
fn to_u8(&self) -> Option<u8>
Converts the value of
self to a u8. If the value cannot be
represented by a u8, then None is returned.Sourcefn to_u16(&self) -> Option<u16>
fn to_u16(&self) -> Option<u16>
Converts the value of
self to a u16. If the value cannot be
represented by a u16, then None is returned.Sourcefn to_u32(&self) -> Option<u32>
fn to_u32(&self) -> Option<u32>
Converts the value of
self to a u32. If the value cannot be
represented by a u32, then None is returned.Sourcefn to_u128(&self) -> Option<u128>
fn to_u128(&self) -> Option<u128>
Converts the value of
self to a u128. If the value cannot be
represented by a u128 (u64 under the default implementation), then
None is returned. Read moreSourceimpl Ord for PercentModifier
impl Ord for PercentModifier
Sourcefn cmp(&self, other: &PercentModifier) -> Ordering
fn cmp(&self, other: &PercentModifier) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq<PercentModifier> for Nat16
impl PartialEq<PercentModifier> for Nat16
Sourceimpl PartialEq<u16> for PercentModifier
impl PartialEq<u16> for PercentModifier
Sourceimpl PartialEq for PercentModifier
impl PartialEq for PercentModifier
Sourceimpl PartialOrd<PercentModifier> for Nat16
impl PartialOrd<PercentModifier> for Nat16
Sourceimpl PartialOrd<u16> for PercentModifier
impl PartialOrd<u16> for PercentModifier
Sourceimpl PartialOrd for PercentModifier
impl PartialOrd for PercentModifier
Sourceimpl Path for PercentModifier
impl Path for PercentModifier
Sourceimpl SanitizeAuto for PercentModifier
impl SanitizeAuto for PercentModifier
fn sanitize_self(&mut self)
fn sanitize_children(&mut self)
fn sanitize_self_with(&mut self, _ctx: &SanitizeContext)
fn sanitize_children_with(&mut self, _ctx: &SanitizeContext)
Sourceimpl SanitizeCustom for PercentModifier
impl SanitizeCustom for PercentModifier
fn sanitize_custom(&mut self)
fn sanitize_custom_with(&mut self, _ctx: &SanitizeContext)
Sourceimpl Serialize for PercentModifier
impl Serialize for PercentModifier
Sourceimpl Sub<PercentModifier> for Nat16
impl Sub<PercentModifier> for Nat16
Sourcetype Output = PercentModifier
type Output = PercentModifier
The resulting type after applying the
- operator.Sourceimpl Sub<u16> for PercentModifier
impl Sub<u16> for PercentModifier
Sourceimpl Sub for PercentModifier
impl Sub for PercentModifier
Sourceimpl SubAssign<u16> for PercentModifier
impl SubAssign<u16> for PercentModifier
Sourcefn sub_assign(&mut self, other: Nat16)
fn sub_assign(&mut self, other: Nat16)
Performs the
-= operation. Read moreSourceimpl SubAssign for PercentModifier
impl SubAssign for PercentModifier
Sourcefn sub_assign(&mut self, other: PercentModifier)
fn sub_assign(&mut self, other: PercentModifier)
Performs the
-= operation. Read moreSourceimpl Sum for PercentModifier
impl Sum for PercentModifier
Sourceimpl UpdateView for PercentModifier
impl UpdateView for PercentModifier
type UpdateViewType = <u16 as UpdateView>::UpdateViewType
Sourcefn merge(&mut self, update: Self::UpdateViewType)
fn merge(&mut self, update: Self::UpdateViewType)
merge the updateview into self
Sourceimpl ValidateAuto for PercentModifier
impl ValidateAuto for PercentModifier
fn validate_children(&self) -> Result<(), ErrorTree>
fn validate_self(&self) -> Result<(), ErrorTree>
fn validate_self_with(&self, _ctx: &ValidateContext) -> Result<(), ErrorTree>
fn validate_children_with( &self, _ctx: &ValidateContext, ) -> Result<(), ErrorTree>
Sourceimpl ValidateCustom for PercentModifier
impl ValidateCustom for PercentModifier
fn validate_custom(&self) -> Result<(), ErrorTree>
fn validate_custom_with(&self, _ctx: &ValidateContext) -> Result<(), ErrorTree>
Sourceimpl View for PercentModifier
impl View for PercentModifier
Sourceimpl Visitable for PercentModifier
impl Visitable for PercentModifier
impl Copy for PercentModifier
impl Eq for PercentModifier
impl StructuralPartialEq for PercentModifier