#[repr(transparent)]pub struct Seconds(pub Nat64);Tuple Fields
0: Nat64Trait Implementations
Sourceimpl AddAssign<u64> for Seconds
impl AddAssign<u64> for Seconds
Sourcefn add_assign(&mut self, other: Nat64)
fn add_assign(&mut self, other: Nat64)
Performs the
+= operation. Read moreSourceimpl AddAssign for Seconds
impl AddAssign for Seconds
Sourcefn add_assign(&mut self, other: Seconds)
fn add_assign(&mut self, other: Seconds)
Performs the
+= operation. Read moreSourceimpl<'de> Deserialize<'de> for Seconds
impl<'de> Deserialize<'de> for Seconds
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Filterable for Seconds
impl Filterable for Seconds
type Filter = <u64 as Filterable>::Filter
type ListFilter = <u64 as Filterable>::ListFilter
Sourceimpl<__derive_more_Rhs> MulAssign<__derive_more_Rhs> for Seconds
impl<__derive_more_Rhs> MulAssign<__derive_more_Rhs> for Seconds
Sourcefn mul_assign(&mut self, __rhs: __derive_more_Rhs)
fn mul_assign(&mut self, __rhs: __derive_more_Rhs)
Performs the
*= operation. Read moreSourceimpl FromPrimitive for Seconds
impl FromPrimitive for Seconds
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u128(n: u128) -> Option<Self>
fn from_u128(n: u128) -> Option<Self>
Converts an
u128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourceimpl ToPrimitive for Seconds
impl ToPrimitive for Seconds
Sourcefn to_i64(&self) -> Option<i64>
fn to_i64(&self) -> Option<i64>
Converts the value of
self to an i64. If the value cannot be
represented by an i64, then None is returned.Sourcefn to_u64(&self) -> Option<u64>
fn to_u64(&self) -> Option<u64>
Converts the value of
self to a u64. If the value cannot be
represented by a u64, then None is returned.Sourcefn to_isize(&self) -> Option<isize>
fn to_isize(&self) -> Option<isize>
Converts the value of
self to an isize. If the value cannot be
represented by an isize, then None is returned.Sourcefn to_i8(&self) -> Option<i8>
fn to_i8(&self) -> Option<i8>
Converts the value of
self to an i8. If the value cannot be
represented by an i8, then None is returned.Sourcefn to_i16(&self) -> Option<i16>
fn to_i16(&self) -> Option<i16>
Converts the value of
self to an i16. If the value cannot be
represented by an i16, then None is returned.Sourcefn to_i32(&self) -> Option<i32>
fn to_i32(&self) -> Option<i32>
Converts the value of
self to an i32. If the value cannot be
represented by an i32, then None is returned.Sourcefn to_i128(&self) -> Option<i128>
fn to_i128(&self) -> Option<i128>
Converts the value of
self to an i128. If the value cannot be
represented by an i128 (i64 under the default implementation), then
None is returned. Read moreSourcefn to_usize(&self) -> Option<usize>
fn to_usize(&self) -> Option<usize>
Converts the value of
self to a usize. If the value cannot be
represented by a usize, then None is returned.Sourcefn to_u8(&self) -> Option<u8>
fn to_u8(&self) -> Option<u8>
Converts the value of
self to a u8. If the value cannot be
represented by a u8, then None is returned.Sourcefn to_u16(&self) -> Option<u16>
fn to_u16(&self) -> Option<u16>
Converts the value of
self to a u16. If the value cannot be
represented by a u16, then None is returned.Sourcefn to_u32(&self) -> Option<u32>
fn to_u32(&self) -> Option<u32>
Converts the value of
self to a u32. If the value cannot be
represented by a u32, then None is returned.Sourcefn to_u128(&self) -> Option<u128>
fn to_u128(&self) -> Option<u128>
Converts the value of
self to a u128. If the value cannot be
represented by a u128 (u64 under the default implementation), then
None is returned. Read moreSourceimpl Ord for Seconds
impl Ord for Seconds
Sourceimpl PartialOrd<Seconds> for Nat64
impl PartialOrd<Seconds> for Nat64
Sourceimpl PartialOrd<u64> for Seconds
impl PartialOrd<u64> for Seconds
Sourceimpl PartialOrd for Seconds
impl PartialOrd for Seconds
Sourceimpl SanitizeAuto for Seconds
impl SanitizeAuto for Seconds
fn sanitize_self(&mut self)
fn sanitize_children(&mut self)
fn sanitize_self_with(&mut self, _ctx: &SanitizeContext)
fn sanitize_children_with(&mut self, _ctx: &SanitizeContext)
Sourceimpl SanitizeCustom for Seconds
impl SanitizeCustom for Seconds
fn sanitize_custom(&mut self)
fn sanitize_custom_with(&mut self, _ctx: &SanitizeContext)
Sourceimpl SubAssign<u64> for Seconds
impl SubAssign<u64> for Seconds
Sourcefn sub_assign(&mut self, other: Nat64)
fn sub_assign(&mut self, other: Nat64)
Performs the
-= operation. Read moreSourceimpl SubAssign for Seconds
impl SubAssign for Seconds
Sourcefn sub_assign(&mut self, other: Seconds)
fn sub_assign(&mut self, other: Seconds)
Performs the
-= operation. Read moreSourceimpl UpdateView for Seconds
impl UpdateView for Seconds
type UpdateViewType = <u64 as UpdateView>::UpdateViewType
Sourcefn merge(&mut self, update: Self::UpdateViewType)
fn merge(&mut self, update: Self::UpdateViewType)
merge the updateview into self
Sourceimpl ValidateAuto for Seconds
impl ValidateAuto for Seconds
fn validate_self(&self) -> Result<(), ErrorTree>
fn validate_children(&self) -> Result<(), ErrorTree>
fn validate_self_with(&self, _ctx: &ValidateContext) -> Result<(), ErrorTree>
fn validate_children_with( &self, _ctx: &ValidateContext, ) -> Result<(), ErrorTree>
Sourceimpl ValidateCustom for Seconds
impl ValidateCustom for Seconds
fn validate_custom(&self) -> Result<(), ErrorTree>
fn validate_custom_with(&self, _ctx: &ValidateContext) -> Result<(), ErrorTree>
impl Copy for Seconds
impl Eq for Seconds
impl StructuralPartialEq for Seconds